@@ -1,4 +1,4 @@
-// Copyright (C) 2000-2020 Free Software Foundation, Inc.
+// Copyright (C) 2000-2022 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -15,48 +15,41 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// The ARM simulator does not provide support for "fstat", which
-// causes "sbumpc" to return an incorrect value.
-// { dg-do run { xfail arm*-*-elf arm*-*-eabi } }
-
 // { dg-require-fileio "" }
 
 #include <cstdio>
 #include <fstream>
+#include <cstring>
 #include <ext/stdio_filebuf.h>
 #include <testsuite_hooks.h>
 
-void test2()
+void test1()
 {
   using namespace std;
 
+  FILE* file = fopen("tmp_10063-1", "w");
+  putc('0', file);
+  putc('1', file);
+  {
+    __gnu_cxx::stdio_filebuf<char> sbuf(file, ios_base::out);
+    sbuf.sputc('2');
+    sbuf.sputc('3');
+  }
+  putc('4', file);	
+  fclose(file);
+
   filebuf fbuf;
-  fbuf.open("tmp_10063-2", ios_base::out | ios_base::trunc);
-  fbuf.sputn("01234", 5);
+  fbuf.open("tmp_10063-1", ios_base::in);	
+  char buf[10];
+  streamsize n = fbuf.sgetn(buf, sizeof(buf));		
   fbuf.close();
 
-  FILE* file = fopen("tmp_10063-2", "r");
-  setbuf(file, 0);
-  int c = getc(file);
-  VERIFY(c == '0');
-  c = getc(file);
-  VERIFY(c == '1');
-  {
-    __gnu_cxx::stdio_filebuf<char> sbuf(file, ios_base::in);
-    c = sbuf.sbumpc();
-    VERIFY(c == '2');
-    c = sbuf.sbumpc();
-    VERIFY(c == '3');
-    c = sbuf.sbumpc();
-    VERIFY(c == '4');
-    c = sbuf.sgetc();
-    VERIFY(c == EOF);
-  }
-  fclose(file);
+  VERIFY(n == 5);
+  VERIFY(!memcmp(buf, "01234", 5)); 
 }
 
 int main()
 {
-  test2();
+  test1();
   return 0;
 }
